# Heartbeat Tasks

This file is automatically checked by the bao agent every 30 minutes.
Add tasks below that you want the agent to perform periodically.

If this file has no tasks (only headings and comments), the agent will skip this heartbeat.

## Active Tasks

<!-- Add your periodic tasks below this line -->


## Completed

<!-- Move completed tasks here or delete them -->
